@@ -3,14 +3,26 @@ from __future__ import unicode_literals
 from django import forms, VERSION as DJANGO_VERSION
 from django.contrib.auth.forms import ReadOnlyPasswordHashField, ReadOnlyPasswordHashWidget
 from django.contrib.auth import get_user_model
-from django.contrib.auth.hashers import UNUSABLE_PASSWORD, identify_hasher
+from django.contrib.auth.hashers import identify_hasher
 from django.utils.translation import ugettext_lazy as _, ugettext
 from django.utils.html import format_html
 
-
 User = get_user_model()
 
 
+def is_password_usable(pw):
+    # like Django's is_password_usable, but only checks for unusable
+    # passwords, not invalidly encoded passwords too.
+    try:
+        # 1.5
+        from django.contrib.auth.hashers import UNUSABLE_PASSWORD
+        return pw != UNUSABLE_PASSWORD
+    except ImportError:
+        # 1.6
+        from django.contrib.auth.hashers import UNUSABLE_PASSWORD_PREFIX
+        return not pw.startswith(UNUSABLE_PASSWORD_PREFIX)
+
+
 class BetterReadOnlyPasswordHashWidget(ReadOnlyPasswordHashWidget):
     """
     A ReadOnlyPasswordHashWidget that has a less intimidating output.
@@ -19,7 +31,7 @@ class BetterReadOnlyPasswordHashWidget(ReadOnlyPasswordHashWidget):
         from django.forms.util import flatatt
         final_attrs = flatatt(self.build_attrs(attrs))
 
-        if not value or value == UNUSABLE_PASSWORD:
+        if not value or not is_password_usable(value):
             summary = ugettext("No password set.")
         else:
             try:
