@@ -1,5 +1,6 @@
 from __future__ import unicode_literals
 
+from django.core.mail import send_mail
 from django.db import models
 from django.contrib.auth.models import AbstractBaseUser, PermissionsMixin
 from django.utils.translation import ugettext_lazy as _
@@ -51,6 +52,11 @@ class AbstractEmailUser(AbstractBaseUser, PermissionsMixin):
     def get_short_name(self):
         return self.email
 
+    def email_user(self, subject, message, from_email=None, **kwargs):
+        """
+        Sends an email to this User.
+        """
+        send_mail(subject, message, from_email, [self.email], **kwargs)
 
 @python_2_unicode_compatible
 class AbstractNamedUser(AbstractEmailUser):
